Enum std::io::CharsError
[−]
[src]
pub enum CharsError {
NotUtf8,
Other(Error),
}An enumeration of possible errors that can be generated from the Chars
adapter.
Variants
NotUtf8 | Variant representing that the underlying stream was read successfully but it did not contain valid utf8 data. | |
Other | Variant representing that an I/O error occurred. |